# System Bridge - Models

This is the models package used by the [System Bridge](https://github.com/timmo001/system-bridge) project.

## Updating models from schemas

To update the models from the schemas, run the following command:

```bash
python ./scripts/generate_models.py
```

This will generate and format the python models in the `systembridgemodels` directory.
